import type { NextPage } from "next";
import Link from "next/link";
import { useRouter } from "next/router";
import { ExpressionSetInfo } from "../../components/ExpressionSetInfo/ExpressionSetInfo";
import { Page } from "../../components/Page";
import { useExpressionData } from "../../hooks/useExpressionData";

const ExpressionSetDetailsPage: NextPage = () => {
  const { query } = useRouter();
  const { expression_sets, expression_to_expression_set } = useExpressionData();

  // Fallback for expression set not found
  const expression_set_id = Number.parseInt(query["set-id"] as string);
  const expression_set = expression_sets.find(
    (item) => item.id === expression_set_id
  );
  if (!expression_set)
    return (
      <Page>
        <div className="page-with-padding scroll">
          <p className="text-details">Expression set not found</p>
        </div>
      </Page>
    );

  // Fallback for expression set empty TODO fix style
  const word_count = expression_to_expression_set.filter(
    (item) => item.expression_set_id === expression_set.id
  ).length;
  if (!word_count)
    return (
      <Page>
        <div className="page-with-padding scroll">
          <ExpressionSetInfo
            id={expression_set.id}
            name={expression_set.name}
            description={expression_set.description}
            word_count={word_count}
          />
          <p className="text-details">No expressions left in this set.</p>
        </div>
      </Page>
    );

  return (
    <Page>
      <div className="page-with-bottom-navigation">
        <section className="padding-small scroll">
          <ExpressionSetInfo
            id={expression_set.id}
            name={expression_set.name}
            description={expression_set.description}
            word_count={word_count}
          />
        </section>
        <section className="navigation-bottom">
          <Link
            href={{
              pathname: "/expression-sets/practice",
              query: { "set-id": expression_set.id },
            }}
            passHref
          >
            <a className="navigation-item-bottom text-navigation grow">
              <span>Practice this set</span>
            </a>
          </Link>
        </section>
      </div>
    </Page>
  );
};

export default ExpressionSetDetailsPage;
