import type { NextPage } from "next";
import Link from "next/link";
import { useRouter } from "next/router";
import { ExpressionCard } from "../../components";
import { Page } from "../../components/Page";
import { useExpressionData } from "../../hooks/useExpressionData";
import { sample } from "../../util/array-utils";
import {
  getCategoriesInExpression,
  getExpressionsInSet,
} from "../../util/data-utils";

const ExpressionSetListPage: NextPage = () => {
  const { query, pathname } = useRouter();
  const {
    expressions,
    categories,
    expression_sets,
    expression_to_expression_set,
    expression_to_category,
  } = useExpressionData();

  // Fallback for expression set not found
  const expression_set = expression_sets.find(
    (item) => item.id === Number.parseInt(query["set-id"] as string)
  );
  if (!expression_set)
    return (
      <Page>
        <p className="text-details">Expression set not found</p>
      </Page>
    );

  // Fallback for expression not found
  const expression_candidates = getExpressionsInSet({
    expression_set_id: expression_set.id,
    expression_to_expression_set,
    expressions,
  });

  if (expression_candidates.length === 0) {
    return (
      <Page>
        <p className="text-details">No expressions left in this set</p>
      </Page>
    );
  }

  // Choose word and find categories
  // Find categories
  const expression = sample(expression_candidates);
  const expression_categories = getCategoriesInExpression({
    categories,
    expression_id: expression.id,
    expression_to_category,
  });

  return (
    <Page>
      <div className="page-with-bottom-navigation">
        <section className="padding-small scroll">
          <ExpressionCard
            prompt={expression.prompt}
            categories={expression_categories.map((category) => category.name)}
            description={expression.description}
            show_description
          />
        </section>
        <section className="navigation-bottom">
          <Link href={{ pathname, query }} passHref>
            <a className="navigation-item-bottom text-navigation grow">
              <div>wrong</div>
            </a>
          </Link>
          <Link href={{ pathname, query }} passHref>
            <a className="navigation-item-bottom text-navigation grow">
              <div>right</div>
            </a>
          </Link>
        </section>
      </div>
    </Page>
  );
};

export default ExpressionSetListPage;
